# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.
#
# Author: Guido Amoruso <guidonte@fluendo.com>


from elisa.core.media_uri import MediaUri
from elisa.core.utils.i18n import install_translation
from elisa.core.utils import defer

from elisa.plugins.poblesec.link import Link

from elisa.plugins.base.models.media import PlayableModel
from elisa.plugins.rss.models import RssFeedModel
from elisa.plugins.rss.models import known_specs

import os


_ = install_translation('qik')


class QikRssFeedModel(RssFeedModel):

    def fill_item_hook(self, item, element):
        """Gstremer breaks with these .flv video"""
        els = element.findall('./{%s}content' % (known_specs['media']))
        supported_video = False
        for el in els:
            type = el.attrib.get('type')
            if type == 'video/mp4':
                supported_video = True
                uri = el.attrib.get('url')
                media_uri = MediaUri(uri)
                playable_model = PlayableModel()
                playable_model.title = item.title
                playable_model.uri = media_uri
                item.playable_model = playable_model
                item.type = 'video'
                break

        if not supported_video:
            self.items.remove(item)
            return

        els = element.findall('./{%s}text' % (known_specs['media']))
        for el in els:
            if el.text.startswith('country:'):
                item.title = el.text[len('country:'):]

        els = element.findall('./{%s}credit' % (known_specs['media']))
        for el in els:
            if el.attrib.get('role') == 'author':
                item.title += ': ' + el.text


def qik_decorator(controller):
    link = Link()
    link.controller_path = '/poblesec/rss_reader'
    link.label = _('Qik Mobile Videos')
    link.icon = 'elisa.plugins.qik.logo'

    feed = QikRssFeedModel()
    feed.uri = MediaUri('http://qik.com/latest_videos')

    link.controller_args = {
        'feed': feed,
        'media_filter': 'video',
    }
    controller.model.append(link)
    return defer.succeed(None)

